@@ -19,7 +19,7 @@
 
 void fun_c_ext ()
 {
-    reg = stringConstructor_cP(
+    reg = *stringConstructor_cP(
                 change_ext(stringStr(top()), stringStr(top() - 1))
                             );
 }
